@@ -122,21 +122,46 @@ sub datetime_to_timepiece {
 }
 
 sub decimal {
-  my ($value, $digits) = @_;
+  my ($value, $digits_tmp) = @_;
   
-  croak "Constraint 'decimal' needs one or two numeric arguments"
-    unless $digits;
+  $DB::single = 1;
   
-  $digits = [$digits] unless ref $digits eq 'ARRAY';
+  # 桁数情報を整理
+  my $digits;
+  if (defined $digits_tmp) {
+    if (ref $digits_tmp eq 'ARRAY') {
+      $digits = $digits_tmp;
+    }
+    else {
+      $digits = [$digits_tmp, undef];
+    }
+  }
+  else {
+    $digits = [undef, undef];
+  }
   
-  $digits->[1] ||= 0;
+  # 正規表現を作成
+  my $re;
+  if (defined $digits->[0] && defined $digits->[1]) {
+    $re = qr/^[0-9]{1,$digits->[0]}(\.[0-9]{0,$digits->[1]})?$/;
+  }
+  elsif (defined $digits->[0]) {
+    $re = qr/^[0-9]{1,$digits->[0]}(\.[0-9]*)?$/;
+  }
+  elsif (defined $digits->[1]) {
+    $re = qr/^[0-9]+(\.[0-9]{0,$digits->[1]})?$/;
+  }
+  else {
+    $re = qr/^[0-9]+(\.[0-9]*)?$/;
+  }
   
-  croak "Constraint 'decimal' needs one or two numeric arguments"
-    unless $digits->[0] =~ /^[0-9]+$/ && $digits->[1] =~ /^[0-9]+$/;
-  
-  return 0 unless defined $value && $value =~ /^[0-9]+(\.[0-9]+)?$/;
-  my $reg = qr/^[0-9]{1,$digits->[0]}(\.[0-9]{0,$digits->[1]})?$/;
-  return $value =~ /$reg/ ? 1 : 0;
+  # 値をチェック
+  if (defined $value && $value =~ /$re/) {
+    return 1;
+  }
+  else {
+    return 0;
+  }
 }
 
 sub duplication {
